@@ -17,9 +17,9 @@ impl<TType> UnconfiguredTypeBuilder<TType> where TType: 'static {
         }
     }
 
-    pub fn build_with_constructor(self, constructor: fn(&mut Injector) -> TType) -> Container {
-        let constructor: Box<dyn Fn(&mut Injector) -> Box<dyn Any>> = Box::new(move |injector: &mut Injector| -> Box<dyn Any> {
-            Box::new((constructor)(injector))
+    pub fn build_with_constructor(self, constructor: fn(&mut Injector) -> Result<TType, crate::DiError>) -> Container {
+        let constructor: Box<dyn Fn(&mut Injector) -> Result<Box<dyn Any>,crate::DiError>> = Box::new(move |injector: &mut Injector| -> Result<Box<dyn Any>,crate::DiError> {
+            Ok(Box::new((constructor)(injector)?))
         });
 
         Container {
@@ -29,9 +29,9 @@ impl<TType> UnconfiguredTypeBuilder<TType> where TType: 'static {
         }
     }
 
-    pub fn build_with_constructor_and_value(self, value: TType, constructor: fn(&mut Injector) -> TType) -> Container {
-        let constructor: Box<dyn Fn(&mut Injector) -> Box<dyn Any>> = Box::new(move |injector: &mut Injector| -> Box<dyn Any> {
-            Box::new((constructor)(injector))
+    pub fn build_with_constructor_and_value(self, value: TType, constructor: fn(&mut Injector) -> Result<TType, crate::DiError>) -> Container {
+        let constructor: Box<dyn Fn(&mut Injector) -> Result<Box<dyn Any>,crate::DiError>> = Box::new(move |injector: &mut Injector| -> Result<Box<dyn Any>,crate::DiError> {
+            Ok(Box::new((constructor)(injector)?))
         });
 
         Container {
